@@ -22,6 +22,8 @@ from suite_py.__version__ import __version__
 
 config = Config()
 
+Package("suite_py", verbose=True).smartupgrade()
+print(f"v{__version__}")
 
 # TODO: fixme -> write something more smart in locating the current project
 def confirm_cwd():
@@ -46,8 +48,6 @@ def confirm_cwd():
 )
 @click.pass_context
 def main(ctx, project, timeout):
-    Package("suite_py", verbose=True).smartupgrade()
-    print(f"suite-py v{__version__}")
     project_name = os.path.basename(project)
     ctx.ensure_object(dict)
     ctx.obj["project"] = project_name
@@ -65,7 +65,9 @@ def cli_create_branch(ctx, card):
 
 
 @main.command("lock", help="Lock di un progetto su staging o prod")
-@click.argument("environment", type=click.Choice(("staging", "production")))
+@click.argument(
+    "environment", type=click.Choice(("staging", "production", "deploy", "merge"))
+)
 @click.pass_context
 def cli_lock_project(ctx, environment):
     project_lock.entrypoint(
@@ -74,7 +76,9 @@ def cli_lock_project(ctx, environment):
 
 
 @main.command("unlock", help="Unlock di un progetto su staging o prod")
-@click.argument("environment", type=click.Choice(("staging", "production")))
+@click.argument(
+    "environment", type=click.Choice(("staging", "production", "deploy", "merge"))
+)
 @click.pass_context
 def cli_unlock_project(ctx, environment):
     project_lock.entrypoint(
