@@ -53,11 +53,12 @@ def entrypoint(project, timeout):
         logger.error("Si è verificato un errore durante il merge.")
         sys.exit(-1)
 
-    drone_build = get_drone_build(project, merge_status.sha)
+    drone_build_number = drone.get_pr_build_number(project, merge_status.sha)
+    drone_build_url = drone.get_build_url(project, drone_build_number)
 
-    if drone_build:
+    if drone_build_url:
         logger.info(
-            f"Pull request mergiata su master! Puoi seguire lo stato della build su {drone_build}"
+            f"Pull request mergiata su master! Puoi seguire lo stato della build su {drone_build_url}"
         )
     else:
         logger.info("Pull request mergiata su master!")
@@ -70,7 +71,13 @@ def entrypoint(project, timeout):
         "Vuoi bloccare staging? (Necessario se bisogna testare su staging)",
         default=False,
     ):
-        captainhook.lock_project(project, "staging")
+        if drone.prestart_success(project, drone_build_number):
+            captainhook.lock_project(project, "staging")
+        else:
+            logger.error(
+                "Problemi con la build su drone, non riesco a bloccare staging"
+            )
+            sys.exit(-1)
 
     if youtrack_id:
         logger.info("Aggiorno lo stato della card su youtrack...")
@@ -129,13 +136,6 @@ def stop_if_master_locked(project, captainhook):
         sys.exit(-1)
 
 
-def get_drone_build(project, sha):
-    drone_build = drone.get_pr_build_url(project, sha)
-    if drone_build != "":
-        return drone_build
-    return None
-
-
 def check_migrations_merge(pr):
     files_changed = [x.filename for x in pr.get_files()]
     if git.migrations_found(files_changed):
